This folder contains a copy of the experimental thermochemistry data used in the 
reaction-network code. Note that currently much of this data is in pymatgen and used 
by the _GibbsComputedStructureEntry_ class; hence this copy is not actually utilized 
in the software here.